@@ -46,7 +46,8 @@ pub enum TitleType {
 	Video = 6,
 	VideoGame = 7,
 	Audiobook = 8,
-	RadioSeries = 9
+	RadioSeries = 9,
+	RadioEpisode = 10
 }
 
 impl From<TitleTypeFromImdb> for TitleType /* {{{ */ {
@@ -61,7 +62,8 @@ impl From<TitleTypeFromImdb> for TitleType /* {{{ */ {
 			TitleTypeFromImdb::Video => Self::Video,
 			TitleTypeFromImdb::VideoGame => Self::VideoGame,
 			TitleTypeFromImdb::Audiobook => Self::Audiobook,
-			TitleTypeFromImdb::RadioSeries => Self::RadioSeries
+			TitleTypeFromImdb::RadioSeries => Self::RadioSeries,
+			TitleTypeFromImdb::RadioEpisode => Self::RadioEpisode
 		}
 	}
 } // }}}
@@ -96,7 +98,8 @@ pub(crate) enum TitleTypeFromImdb {
 	Video,
 	VideoGame,
 	Audiobook,
-	RadioSeries
+	RadioSeries,
+	RadioEpisode
 }
 
 impl<'de> Deserialize<'de> for TitleTypeFromImdb {
@@ -113,7 +116,8 @@ impl<'de> Deserialize<'de> for TitleTypeFromImdb {
 			"videoGame" => Self::VideoGame,
 			"audiobook" => Self::Audiobook,
 			"radioSeries" => Self::RadioSeries,
-			s => return Err(serde::de::Error::invalid_value(Unexpected::Str(&s), &"'short', 'movie', 'tvEpisode', 'tvMiniSeries', 'tvMovie', 'tvSeries', 'tvShort', 'tvSpecial', 'video', 'videoGame'"))
+			"radioEpisode" => Self::RadioEpisode,
+			s => return Err(serde::de::Error::invalid_value(Unexpected::Str(&s), &"'short', 'episode', 'tvEpisode', 'movie', 'tvMovie', 'tvSeries', 'tvMiniSeries', 'tvShort', 'tvSpecial', 'video', 'videoGame', 'audiobook', 'radioSeries', 'radioEpisode'"))
 		})
 	}
 }
